pub struct OkuFsConfig { /* private fields */ }Expand description
Configuration of an Oku file system node.
Implementations
Sourceimpl OkuFsConfig
impl OkuFsConfig
Sourcepub fn load_or_create_config() -> Result<Self>
pub fn load_or_create_config() -> Result<Self>
Loads the configuration of the file system from disk, or creates a new configuration if none exists.
Returns
The configuration of the file system.
Sourcepub fn get_republish_delay(&self) -> Duration
pub fn get_republish_delay(&self) -> Duration
Gets OkuFsConfig::republish_delay.
Returns
OkuFsConfig::republish_delay if set, or crate::discovery::DEFAULT_REPUBLISH_DELAY otherwise.
Sourcepub fn set_republish_delay(
&self,
republish_delay: &Option<Duration>,
) -> Result<()>
pub fn set_republish_delay( &self, republish_delay: &Option<Duration>, ) -> Result<()>
Sets OkuFsConfig::republish_delay.
Arguments
republish_delay- An optional republish delay; if unspecified, the default will be used.
Sourcepub fn get_initial_publish_delay(&self) -> Duration
pub fn get_initial_publish_delay(&self) -> Duration
Gets OkuFsConfig::initial_publish_delay.
Returns
OkuFsConfig::initial_publish_delay if set, or crate::discovery::DEFAULT_INITIAL_PUBLISH_DELAY otherwise.
Sourcepub fn set_initial_publish_delay(
&self,
initial_publish_delay: &Option<Duration>,
) -> Result<()>
pub fn set_initial_publish_delay( &self, initial_publish_delay: &Option<Duration>, ) -> Result<()>
Sets OkuFsConfig::initial_publish_delay.
Arguments
initial_publish_delay- An optional initial publish delay; if unspecified, the default will be used.